@@ -54,8 +54,6 @@ __all__ = (
 # -----------------------------------------------------------------------------
 # SI prefixes
 # -----------------------------------------------------------------------------
-from typing import List
-
 quetta = 1.0e30
 ronna = 1.0e27
 yotta = 1.0e24
@@ -99,5 +97,5 @@ yobi = 2.0**80
 googol = 1.0e100
 
 
-def __dir__() -> List[str]:
+def __dir__() -> list[str]:
     return list(__all__)
